@@ -1,11 +1,12 @@
 import F.OS
-from FairResources.Sources import Sources
+from FairResources.FairResources import Sources
 import os
 import re
 import pandas
 import feedparser
 import random
 from F import LIST
+import json
 
 TRENDING_URL = 'http://www.google.com/trends/hottrends/atom/feed?pn=p1'
 
@@ -39,15 +40,19 @@ PUNKT_ONE = "/tokenizers/punkt/english.pickle"
 PUNKT_TWO = "/tokenizers/punkt/PY3/english.pickle"
 NLTK_PUNKT_ONE = f"{str(CWD)}{PUNKT_ONE}"
 NLTK_PUNKT_TWO = f"{str(CWD)}{PUNKT_TWO}"
-
 STOCKTICKERS = os.path.join(os.path.dirname(__file__), 'stocks.csv')
-SOURCES = Sources
-REDDIT_COMMUNITIES = Sources.reddit_communities
-TWITTER_USERS = Sources.twitter_users
-
+SOURCES = Sources.Sources
+REDDIT_COMMUNITIES = SOURCES.reddit_communities
+TWITTER_USERS = SOURCES.twitter_users
 ALL = [a for a in os.scandir(os.path.dirname(__file__))]
 
+def load_json(fileName):
+    f = open(f'{CWD}/{fileName}.json')
+    data = json.load(f)
+    return data
 
+def load_txt(fileName):
+    return F.OS.get_file_BY_searchTerm(fileName, directoryPath=FILE_PATH)
 
 def get_source(sourceTerm):
     return F.OS.get_file_BY_searchTerm(sourceTerm, directoryPath=FILE_PATH)
@@ -171,3 +176,4 @@ def to_tokens(text):
         return [x.strip('.').lower() for x in text.split()]
     except TypeError:
         return None
+
